### MDS analysis for 11 languages
### Version 3.0 
### Created by Jianjing Kuang
### Date 03/01/2022

#### load packages
library(MASS)
library(vegan)
library(cluster)
library(dplyr)


## load functions

####### color function
source("color7.r")
source("11colors_6.r")

####### read in dataset
data_mm=read.csv("lg11_normalized_20220301.csv")

####### attach and combine data with group mean
attach(data_mm)
h1h2=tapply(H1H2c_means002,Lg_phon,mean,na.rm=T)
h2h4=tapply(H2H4c_means002, Lg_phon,mean,na.rm=T)
h1a1=tapply(H1A1c_means002, Lg_phon,mean,na.rm=T)
h1a2=tapply(H1A2c_means002, Lg_phon,mean,na.rm=T)
h1a3=tapply(H1A3c_means002, Lg_phon,mean,na.rm=T)
cpp=tapply(CPP_means002, Lg_phon,mean,na.rm=T)
energy=tapply(Energy_means002,Lg_phon,mean,na.rm=T)
hnr05=tapply(HNR05_means002,Lg_phon,mean,na.rm=T)
hnr15=tapply(HNR15_means002,Lg_phon,mean,na.rm=T)
hnr25=tapply(HNR25_means002,Lg_phon,mean,na.rm=T)
hnr35=tapply(HNR35_means002,Lg_phon,mean,na.rm=T)
h1=tapply(H1c_means002,Lg_phon,mean,na.rm=T)
h2=tapply(H2c_means002, Lg_phon,mean,na.rm=T)
h4=tapply(H4c_means002, Lg_phon,mean,na.rm=T)
a1=tapply(A1c_means002, Lg_phon,mean,na.rm=T)
a2=tapply(A2c_means002, Lg_phon,mean,na.rm=T)
a3=tapply(A3c_means002, Lg_phon,mean,na.rm=T)
shr=tapply(SHR_means002, Lg_phon,mean,na.rm=T)
soe=tapply(soe_means002, Lg_phon,mean,na.rm=T)
h42k=tapply(H42Kc_means002,Lg_phon,mean,na.rm=T)
h2kh5k=tapply(H2KH5Kc_means002, Lg_phon,mean,na.rm=T)
f0=tapply(strF0_means002,Lg_phon,mean,na.rm=T)
mmean3=cbind(h1h2,h2h4,h1a1,h1a2,h1a3,h42k, h2kh5k,h1,h2,h4,a1,a2,a3,cpp,hnr05,hnr15,hnr25,hnr35,soe,shr,energy)


####################################################################### 
#for the purpose of plotting only. Read in the mean values and plot MDS
#######################################################################

rownames(mmean3)[c(9,10)]=c("LuL","LuT")

#### calculate distance and MDS
mds <- metaMDS(mmean3,distance ="manhattan",wascores = TRUE,old.wa = TRUE,k=3)
set.seed(23456)
#####MDS 2D plot
pdf("mds_plot_fig4_20211127.pdf",width=6,height=6)
plot(mds$points[,c(1,2)],xlim=c(-4,3),type="n",xlab="Dimension 1",ylab="Dimension 2")
points(mds$points[,c(1,2)],type="p",pch=16,col=col.palette,cex=1.5)
text(mds$points[,c(1,2)],labels=as.character(rownames(mmean3)),pos = 2, offset = 0.5)
dev.off()

pdf("mds_plot_fig6_20211127.pdf",width=12,height=6)
par(mfrow=c(1,2))
plot(mds$points[,c(1,3)],xlim=c(-4,3),type="n",xlab="Dimension 1",ylab="Dimension 3")
points(mds$points[,c(1,3)],type="p",pch=16,col=col.palette,cex=1.5)
text(mds$points[,c(1,3)],labels=as.character(rownames(mmean3)),pos = 2, offset = 0.5,cex=0.8)

plot(mds$points[,c(2,3)],xlim=c(-4,3),type="n",xlab="Dimension 2",ylab="Dimension 3")
points(mds$points[,c(2,3)],type="p",pch=16,col=col.palette,cex=1.5)
text(mds$points[,c(2,3)],labels=as.character(rownames(mmean3)),pos = 2, offset = 0.5,cex=0.8)
dev.off()

#color code: 11colors_6
pdf("mds_plot_fig5_20211127.pdf",width=6,height=6)
plot(x=mds$points[,1],y=-mds$points[,2],xlim=c(-4,3),type="n",xlab="Dimension 1",ylab="Dimension 2")
points(x=mds$points[,1],y=-mds$points[,2],type="p",pch=16,col=col.palette,cex=1.5)
text(x=mds$points[,1],y=-mds$points[,2],labels=as.character(rownames(mmean3)),pos = 2, offset = 0.5,cex=0.8)
dev.off()
###### weight
weights=abs(mds$species)
weights
